import Image from "next/image";

import { ArrowLeft, ArrowRight } from "lucide-react";

import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { ProductDetailsBlogFeature } from "@/utils/get-fake-data";

import BlurFade from "../ui/blur-fade";

interface FeatureCardProps {
	feature: ProductDetailsBlogFeature;
	locale: Locale;
	index: number;
}

export function ProductFeatureBlogCard({
	feature,
	locale,
	index,
}: FeatureCardProps) {
	const isRTL = locale === "ar";

	return (
		<BlurFade
			inView
			direction="up"
			delay={index * 0.5}
			className="relative overflow-hidden rounded-3xl border-2 border-[#FFFFFF21] bg-[#2895C8A6] p-8 backdrop-blur-lg"
		>
			<div className="relative aspect-[4/3] overflow-hidden rounded-2xl">
				<Image
					src={feature.image}
					alt={feature.title?.[locale]}
					fill
					className="object-cover"
				/>
			</div>
			<div className="mt-4 space-y-4">
				<div className="flex flex-wrap gap-2">
					{feature.tags?.map((tag) => (
						<span
							key={tag.id}
							className="border-b-[1px] border-b-[#BCBCBC] py-1 text-sm text-white"
						>
							{tag.label?.[locale]}
						</span>
					))}
				</div>
				<p
					className={cn(
						"text-2xl text-white",
						isRTL && "font-arabic text-right"
					)}
				>
					{feature.title?.[locale]}
				</p>
				<p
					className={cn(
						isRTL && "font-arabic text-right",
						"text-justify text-base font-normal text-white/90"
					)}
				>
					{feature.description?.[locale]}
				</p>
				<button
					className={cn(
						"inline-flex items-center gap-2 rounded-full bg-white p-2 text-custom-primary-accent transition-colors hover:bg-white/20",
						isRTL && "font-arabic"
					)}
				>
					{isRTL ? (
						<ArrowLeft className="h-8 w-8" />
					) : (
						<ArrowRight className="h-8 w-8" />
					)}
				</button>
			</div>
		</BlurFade>
	);
}
